CacheSetup class

Cache configuration for offline support Currently disabled - will be re-enabled with proper cache implementation

Constructors

CacheSetup()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

clearCache() Future<void>
Clear all cached data
getCacheInterceptor() → Interceptor?
Get cache interceptor for Dio
getCacheSize() Future<int>
Get cache size in bytes
initialize({int maxStaleHours = 24}) Future<void>
Initialize cache