ProdobitClient class
Main Prodobit client for accessing all SDK functionality
Constructors
-
ProdobitClient({required String baseUrl, String apiVersion = 'v1', Duration timeout = const Duration(seconds: 30), bool enableLogging = false, Map<
String, String> headers = const {}}) -
Create a new Prodobit client instance
factory
- ProdobitClient.withConfig(ProdobitConfig config)
-
Create client with custom configuration
factory
Properties
- apiClient → ApiClient
-
Get the underlying API client (for advanced usage)
no setter
- asset ↔ AssetService
-
latefinal
- assetAssignment ↔ AssetAssignmentService
-
latefinal
- assetIssue ↔ AssetIssueService
-
latefinal
- auth ↔ AuthService
-
latefinal
- calibration ↔ CalibrationService
-
latefinal
- config → ProdobitConfig
-
final
- employee ↔ EmployeeService
-
latefinal
- file ↔ FileService
-
latefinal
- hashCode → int
-
The hash code for this object.
no setterinherited
- inventory ↔ InventoryService
-
latefinal
- location ↔ LocationService
-
latefinal
- maintenance ↔ MaintenanceService
-
latefinal
- manufacturing ↔ ManufacturingService
-
latefinal
- party ↔ PartyService
-
latefinal
- purchase ↔ PurchaseService
-
latefinal
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sales ↔ SalesService
-
latefinal
- task ↔ TaskService
-
latefinal
- tenant ↔ TenantService
-
latefinal
- user ↔ UserService
-
latefinal
Methods
-
clearAuth(
) → void - Clear authentication
-
initialize(
) → Future< void> - Initialize the client (call this on app start)
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setAuthToken(
String token) → void - Set authentication token manually
-
setOrganization(
String organizationId) → void - Set organization context
-
toString(
) → String -
A string representation of this object.
inherited
-
updateConfig(
ProdobitConfig newConfig) → ProdobitClient - Update client configuration
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited