ApiException class

Exception thrown when API calls fail

Inheritance

Constructors

ApiException(String message, {String? code, Map<String, dynamic>? details, int? statusCode, Map<String, dynamic>? response})
const
ApiException.fromStatusCode(int statusCode, {String? message, Map<String, dynamic>? response})
Create an ApiException from HTTP status code
factory

Properties

code String?
finalinherited
details Map<String, dynamic>?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
message String
finalinherited
response Map<String, dynamic>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited