AuthException class

Exception thrown when authentication fails

Inheritance

Constructors

AuthException(String message, {String? code, Map<String, dynamic>? details})
const
AuthException.invalidCredentials()
Invalid credentials
factory
AuthException.invalidToken()
Token invalid
factory
AuthException.refreshFailed()
Refresh token failed
factory
AuthException.required()
Authentication required
factory
AuthException.tokenExpired()
Token expired
factory

Properties

code String?
finalinherited
details Map<String, dynamic>?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
message String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited