Asset class sealed
Asset model
- Annotations
-
- @freezed
Constructors
- Asset({required String id, required String tenantId, required String locationId, required String name, required String code, required String status, required DateTime insertedAt, required DateTime updatedAt, String? parentAssetId, String? assetTypeId, String? serialNumber, String? qrCode, String? imageUrl, DateTime? deletedAt})
-
constfactory
-
Asset.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited