AssetAssignment class sealed

Asset Assignment model

Annotations
  • @freezed

Constructors

AssetAssignment({required String id, required String tenantId, required String assetId, required String assignedTo, required String assignedType, required String assignedBy, required DateTime assignmentDate, required String status, required DateTime insertedAt, required DateTime updatedAt, String? expectedReturnDate, DateTime? actualReturnDate, String? transferredToAssignmentId, String? notes, String? signatureImageId, String? assignmentReason, String? returnCondition, DateTime? deletedAt, AssetInfo? asset})
const
factory
AssetAssignment.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited