Constructors
-
AssetIssue({required String id, required String tenantId, required String assetId, required String title, required String description, required String category, required String severity, required String status, required String reportedBy, required DateTime reportedAt, required DateTime insertedAt, required DateTime updatedAt, String? assignedTo, String? relatedTaskId, DateTime? acknowledgedAt, DateTime? resolvedAt, DateTime? closedAt, int? estimatedResolutionTime, int? actualResolutionTime, String? resolutionNotes, String? rootCause, String? correctiveActions, String? preventiveActions, List<String>? imageIds, List<String>? documentIds, String? location, String? impactDescription, bool? downtime, DateTime? deletedAt})
-
const
factory
-
AssetIssue.fromJson(Map<String, dynamic> json)
-
factory
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited