UpdateAssetIssueRequest class sealed

Annotations
  • @freezed

Constructors

UpdateAssetIssueRequest({String? title, String? description, String? category, String? severity, String? status, String? assignedTo, int? estimatedResolutionTime, int? actualResolutionTime, String? resolutionNotes, String? rootCause, String? correctiveActions, String? preventiveActions, List<String>? imageIds, List<String>? documentIds, String? location, String? impactDescription, bool? downtime})
const
factory
UpdateAssetIssueRequest.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited