LoginOTPResponse class sealed

Login OTP response model

Annotations
  • @freezed

Constructors

LoginOTPResponse({required bool success, LoginResponseData? data, String? message})
const
factory
LoginOTPResponse.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited