OTPResponse class sealed
OTP response model
- Annotations
-
- @freezed
Constructors
-
OTPResponse({required bool success, required String message, String? expiresAt, bool? requiresTenantSelection, bool? isNewUser, String? defaultTenantId, String? defaultTenantName, String? selectedTenantId, String? selectedTenantName, List<
TenantInfo> ? tenants}) -
constfactory
-
OTPResponse.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited