OrganizationInfo class sealed

Organization info model (deprecated - use TenantInfo)

Annotations

Constructors

OrganizationInfo({required String id, required String name, required String plan, required bool isActive, String? domain, Map<String, dynamic>? settings})
const
factory
OrganizationInfo.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited