UserData class sealed

User data model

Annotations
  • @freezed

Constructors

UserData({required String id, required bool twoFactorEnabled, required String status, required String insertedAt, required String updatedAt, String? displayName, String? twoFactorSecret, String? deletedAt})
const
factory
UserData.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited