UserProfile class sealed

User profile model (deprecated - use UserData)

Annotations

Constructors

UserProfile({required String id, required String email, required String firstName, required String lastName, required List<String> roles, required bool isActive, required DateTime createdAt, String? avatar, DateTime? updatedAt, Map<String, dynamic>? metadata})
const
factory
UserProfile.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited