Address class sealed

Address model

Annotations
  • @freezed

Constructors

Address({String? street, String? city, String? state, String? country, String? zipCode, double? latitude, double? longitude})
const
factory
Address.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited