ApiResponse<T> class sealed

Generic API response wrapper

Annotations
  • @Freezed.new(genericArgumentFactories: true)

Constructors

ApiResponse({required bool success, T? data, String? message, String? error, Map<String, dynamic>? metadata, String? errorCode})
const
factory
ApiResponse.fromJson(Map<String, dynamic> json, T fromJsonT(Object?))
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited