FileUploadResponse class sealed

File upload response

Annotations
  • @freezed

Constructors

FileUploadResponse({required String id, required String filename, required String originalName, required String mimeType, required int size, required String url, Map<String, dynamic>? metadata})
const
factory
FileUploadResponse.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited