QueryParams class sealed

Query parameters for list requests

Annotations
  • @freezed

Constructors

QueryParams({@Default.new(1) int page, @Default.new(20) int limit, String? search, String? sortBy, @Default.new('asc') String sortOrder, Map<String, String>? filters})
const
factory
QueryParams.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toQueryMap() Map<String, dynamic>
Convert to query parameters map
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited