ItemRequest class sealed

Item creation/update request

Annotations
  • @freezed

Constructors

ItemRequest({required String name, required String code, required String type, required String unit, String? description, String? category, String? brand, Money? basePrice, Money? costPrice, String? barcode, String? imageUrl, @Default.new(true) bool isActive, Map<String, dynamic>? specifications, Map<String, dynamic>? metadata})
const
factory
ItemRequest.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited