Location class sealed
Location model
- Annotations
-
- @freezed
Constructors
-
Location({required String id, required String name, required String code, required String status, required DateTime insertedAt, required DateTime updatedAt, String? tenantId, String? description, String? type, String? parentId, String? parentLocationId, String? locationTypeId, DateTime? deletedAt, Address? address, ContactInfo? contactInfo, Map<
String, dynamic> ? metadata}) -
constfactory
-
Location.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited