StockAdjustmentRequest class sealed

Stock adjustment request

Annotations
  • @freezed

Constructors

StockAdjustmentRequest({required String itemId, required String locationId, required double quantity, required String reason, String? notes, Money? cost})
const
factory
StockAdjustmentRequest.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited