StockMovement class sealed
Stock movement model
- Annotations
-
- @freezed
Constructors
- StockMovement({required String id, required String itemId, required String locationId, required String type, required double quantity, required DateTime movementDate, required AuditInfo auditInfo, double? cost, String? referenceType, String? referenceId, String? notes})
-
constfactory
-
StockMovement.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited