PhysicalInventory class sealed

Physical inventory model

Annotations
  • @freezed

Constructors

PhysicalInventory({required String id, required String name, required String description, required String locationId, required String status, required DateTime createdAt, required DateTime updatedAt, DateTime? startedAt, DateTime? completedAt, DateTime? cancelledAt, String? createdBy, String? startedBy, String? completedBy, String? cancelledBy, Map<String, dynamic>? metadata})
const
factory
PhysicalInventory.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited