UpdatePhysicalInventoryItemRequest class sealed

Update physical inventory item request

Annotations
  • @freezed

Constructors

UpdatePhysicalInventoryItemRequest({required double countedQuantity, String? notes, String? lotNumber, String? serialNumber})
const
factory
UpdatePhysicalInventoryItemRequest.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited