CreateStockReservationRequest class sealed
Create stock reservation request
- Annotations
-
- @freezed
Constructors
-
CreateStockReservationRequest({required String itemId, required String locationId, required double quantity, required String purpose, String? referenceId, String? referenceType, String? notes, DateTime? expiresAt, Map<
String, dynamic> ? metadata}) -
constfactory
-
CreateStockReservationRequest.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited