CreateMaintenancePlanRequest class
sealed
Constructors
-
CreateMaintenancePlanRequest({required String assetId, required String name, required String type, required String frequency, required DateTime startDate, String? description, DateTime? endDate, int? intervalDays, int? intervalHours, int? intervalCycles, int? estimatedDurationHours, String? assignedTeamId, String? defaultAssigneeId, String? priority, String? instructions, Map<String, dynamic>? checklistItems, List<String>? requiredSkills, String? safetyPrecautions, Map<String, dynamic>? requiredMaterials, Map<String, dynamic>? spareParts, bool? autoCreateTask, int? taskCreationLeadDays, List<String>? imageIds, List<String>? documentIds, String? procedureDocumentId})
-
const
factory
-
CreateMaintenancePlanRequest.fromJson(Map<String, dynamic> json)
-
factory
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited