MaintenanceRecord class sealed

Annotations
  • @freezed

Constructors

MaintenanceRecord({required String id, required String tenantId, required String maintenancePlanId, required String assetId, required String taskId, required DateTime scheduledDate, required String status, required DateTime insertedAt, required DateTime updatedAt, DateTime? completedDate, String? performedBy, int? durationHours, String? notes, String? issuesFound, Map<String, dynamic>? partsReplaced, Map<String, dynamic>? materialsUsed, DateTime? nextRecommendedDate, List<String>? imageIds, List<String>? documentIds})
const
factory
MaintenanceRecord.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited