UpdateMaintenancePlanRequest class
sealed
Constructors
-
UpdateMaintenancePlanRequest({String? name, String? description, String? type, String? frequency, String? status, DateTime? startDate, DateTime? endDate, DateTime? nextScheduledDate, int? intervalDays, int? intervalHours, int? intervalCycles, int? estimatedDurationHours, String? assignedTeamId, String? defaultAssigneeId, String? priority, String? instructions, Map<String, dynamic>? checklistItems, List<String>? requiredSkills, String? safetyPrecautions, Map<String, dynamic>? requiredMaterials, Map<String, dynamic>? spareParts, bool? autoCreateTask, int? taskCreationLeadDays, List<String>? imageIds, List<String>? documentIds, String? procedureDocumentId})
-
const
factory
-
UpdateMaintenancePlanRequest.fromJson(Map<String, dynamic> json)
-
factory
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited