UpdateMaintenanceRecordRequest class
sealed
Constructors
-
UpdateMaintenanceRecordRequest({String? status, DateTime? completedDate, String? performedBy, int? durationHours, String? notes, String? issuesFound, Map<String, dynamic>? partsReplaced, Map<String, dynamic>? materialsUsed, DateTime? nextRecommendedDate, List<String>? imageIds, List<String>? documentIds})
-
const
factory
-
UpdateMaintenanceRecordRequest.fromJson(Map<String, dynamic> json)
-
factory
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited