CreateBomQuickRequest class sealed

Create BOM quick request

Annotations
  • @freezed

Constructors

CreateBomQuickRequest({required String itemId, required String name, required String version, required List<BomQuickComponent> components, String? description})
const
factory
CreateBomQuickRequest.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited