CreateEcoRequest class sealed

Create ECO request

Annotations
  • @freezed

Constructors

CreateEcoRequest({required String ecoNumber, required String title, required String description, required String type, required String priority, required String reason, DateTime? targetImplementationDate, double? estimatedCost, int? estimatedHours, List<String>? affectedBomIds, List<String>? affectedItemIds, Map<String, dynamic>? metadata})
const
factory
CreateEcoRequest.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited