WorkOrder class sealed

Work order model

Annotations
  • @freezed

Constructors

WorkOrder({required String id, required String workOrderNumber, required String itemId, required double quantity, required String status, DateTime? plannedStartDate, DateTime? plannedEndDate, DateTime? actualStartDate, DateTime? actualEndDate, String? bomId, String? priority, String? notes, Map<String, dynamic>? metadata})
const
factory
WorkOrder.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited