CreateContactMechanismRequest class sealed

Create contact mechanism request

Annotations
  • @freezed

Constructors

CreateContactMechanismRequest({required String type, required String value, bool? isPrimary, String? label, String? extension, String? countryCode, String? notes, DateTime? validFrom, DateTime? validTo})
const
factory
CreateContactMechanismRequest.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited