UpdateAddressRequest class sealed

Update address request

Annotations
  • @freezed

Constructors

UpdateAddressRequest({String? addressLine1, String? addressLine2, String? addressLine3, String? city, String? state, String? postalCode, String? country, String? region, bool? isPrimary, bool? isActive, String? label, String? notes, double? latitude, double? longitude, DateTime? validFrom, DateTime? validTo})
const
factory
UpdateAddressRequest.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited