CreateOrganizationCustomerRequest class sealed

Create organization customer request

Annotations
  • @freezed

Constructors

CreateOrganizationCustomerRequest({required String name, String? legalName, String? email, String? phone, String? website, String? taxId, String? registrationNumber, String? industry, String? notes, Map<String, dynamic>? attributes})
const
factory
CreateOrganizationCustomerRequest.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited