CreatePersonRequest class sealed

Create person request

Annotations
  • @freezed

Constructors

CreatePersonRequest({required String firstName, required String lastName, String? middleName, String? salutation, String? suffix, String? nickname, DateTime? birthDate, String? gender, String? maritalStatus, String? occupation, String? notes, List<String>? roles, Map<String, dynamic>? attributes})
const
factory
CreatePersonRequest.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited