CreatePartyRequest class sealed
Party creation request
- Annotations
-
- @freezed
Constructors
-
CreatePartyRequest({required String name, required String type, String? code, String? email, String? phone, String? taxId, Address? address, ContactInfo? contactInfo, Map<
String, dynamic> ? metadata}) -
constfactory
-
CreatePartyRequest.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited