Party class sealed

Party (customer/supplier) model

Annotations
  • @freezed

Constructors

Party({required String id, required String name, required String type, required DateTime createdAt, String? code, String? email, String? phone, String? taxId, Address? address, ContactInfo? contactInfo, String? organizationId, bool? isActive, DateTime? updatedAt, Map<String, dynamic>? metadata})
const
factory
Party.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited