CreatePurchaseOrderLineItemRequest class sealed
Create purchase order line item request
- Annotations
-
- @freezed
Constructors
-
CreatePurchaseOrderLineItemRequest({required String itemId, required double quantity, required String unit, required double unitPrice, double? discountAmount, double? taxAmount, int? sequence, DateTime? requestedDeliveryDate, String? notes, String? specification, Map<
String, dynamic> ? attributes}) -
constfactory
-
CreatePurchaseOrderLineItemRequest.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited