PurchaseOrder class sealed

Purchase order model

Annotations
  • @freezed

Constructors

PurchaseOrder({required String id, required String orderNumber, required String supplierId, required String status, required DateTime orderDate, required double totalAmount, required double taxAmount, required double netAmount, required DateTime createdAt, required DateTime updatedAt, DateTime? deliveryDate, DateTime? acknowledgedAt, DateTime? approvedAt, DateTime? sentAt, DateTime? cancelledAt, DateTime? closedAt, String? createdBy, String? approvedBy, String? cancelledBy, String? notes, String? termsAndConditions, String? paymentTerms, String? deliveryAddress, String? billingAddress, Map<String, dynamic>? metadata})
const
factory
PurchaseOrder.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited