PurchaseOrderLineItem class sealed
Purchase order line item model
- Annotations
-
- @freezed
Constructors
-
PurchaseOrderLineItem({required String id, required String purchaseOrderId, required String itemId, required double quantity, required String unit, required double unitPrice, required double totalPrice, required double discountAmount, required double taxAmount, required double netAmount, required String status, int? sequence, DateTime? requestedDeliveryDate, DateTime? confirmedDeliveryDate, double? receivedQuantity, double? returnedQuantity, String? notes, String? specification, Map<
String, dynamic> ? attributes, Map<String, dynamic> ? metadata}) -
constfactory
-
PurchaseOrderLineItem.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited