UpdatePurchaseOrderLineItemRequest class sealed

Update purchase order line item request

Annotations
  • @freezed

Constructors

UpdatePurchaseOrderLineItemRequest({double? quantity, String? unit, double? unitPrice, double? discountAmount, double? taxAmount, int? sequence, DateTime? requestedDeliveryDate, DateTime? confirmedDeliveryDate, String? notes, String? specification, Map<String, dynamic>? attributes})
const
factory
UpdatePurchaseOrderLineItemRequest.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited