CreateRFQLineItemRequest class sealed

Create RFQ line item request

Annotations
  • @freezed

Constructors

CreateRFQLineItemRequest({required String itemId, required double quantity, required String unit, required DateTime requiredDate, int? sequence, String? specification, String? brandPreference, String? notes, double? budgetPrice, double? maxPrice, Map<String, dynamic>? technicalRequirements, Map<String, dynamic>? attributes})
const
factory
CreateRFQLineItemRequest.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited