CreateRFQRequest class sealed

Create RFQ request

Annotations
  • @freezed

Constructors

CreateRFQRequest({required String title, required String description, required DateTime responseDeadline, String? department, String? project, String? deliveryLocation, String? paymentTerms, String? evaluationCriteria, String? notes, String? termsAndConditions, List<String>? supplierIds, List<CreateRFQLineItemRequest>? lineItems, Map<String, dynamic>? metadata})
const
factory
CreateRFQRequest.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited