RFQ class sealed

Request for Quotation (RFQ) model

Annotations
  • @freezed

Constructors

RFQ({required String id, required String rfqNumber, required String title, required String description, required String status, required DateTime rfqDate, required DateTime responseDeadline, required DateTime createdAt, required DateTime updatedAt, DateTime? sentAt, DateTime? closedAt, DateTime? cancelledAt, String? createdBy, String? closedBy, String? cancelledBy, String? department, String? project, String? deliveryLocation, String? paymentTerms, String? evaluationCriteria, String? notes, String? termsAndConditions, List<String>? supplierIds, Map<String, dynamic>? metadata})
const
factory
RFQ.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited