QuotationComparison class sealed
Quotation comparison model
- Annotations
-
- @freezed
Constructors
-
QuotationComparison({required String itemId, required String itemName, required double quantity, required String unit, required List<
QuotationComparisonEntry> quotations, String? recommendation, Map<String, dynamic> ? analysis}) -
constfactory
-
QuotationComparison.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited