QuotationComparisonEntry class sealed

Quotation comparison entry

Annotations
  • @freezed

Constructors

QuotationComparisonEntry({required String quotationId, required String supplierId, required String supplierName, required double unitPrice, required double totalPrice, required int leadTimeDays, DateTime? deliveryDate, String? brandModel, String? notes, double? score, Map<String, dynamic>? metrics})
const
factory
QuotationComparisonEntry.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited