AuthResponse class sealed

Authentication response model (deprecated - use auth models)

Annotations
  • @Deprecated('Use LoginOTPResponse from auth_models.dart instead')
  • @freezed

Constructors

AuthResponse({required String accessToken, required String refreshToken, required String tokenType, required int expiresIn, String? organizationId, String? organizationName})
const
factory
AuthResponse.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited