UpdateSalesOrderRequest class sealed

Update sales order request

Annotations
  • @freezed

Constructors

UpdateSalesOrderRequest({String? orderNumber, DateTime? orderDate, DateTime? deliveryDate, String? status, String? notes, Map<String, dynamic>? metadata})
const
factory
UpdateSalesOrderRequest.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited