CreateTenantRequest class sealed

Create tenant request

Annotations
  • @freezed

Constructors

CreateTenantRequest({required String name, required String slug, String? description, String? domain, String? contactEmail, String? contactPhone, String? address, String? timezone, String? currency, String? language, Map<String, dynamic>? settings, Map<String, dynamic>? metadata})
const
factory
CreateTenantRequest.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited