UpdateMembershipRequest class sealed

Update membership request

Annotations
  • @freezed

Constructors

UpdateMembershipRequest({String? role, String? status, List<String>? permissions, Map<String, dynamic>? metadata})
const
factory
UpdateMembershipRequest.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited