Auth class

Auth state notifier

Annotations
  • @riverpod

Constructors

Auth()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build() Future<AuthState>
logout({bool allDevices = false}) Future<void>
Logout
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
requestOTP({required String email, String? tenantId}) Future<void>
Request OTP for email login
resendOTP(String email) Future<void>
Resend OTP
switchTenant(String tenantId) Future<void>
Switch tenant
toString() String
A string representation of this object.
inherited
verifyOTP({required String email, required String code, String? tenantId}) Future<void>
Verify OTP and complete login

Operators

operator ==(Object other) bool
The equality operator.
inherited