OTPState class sealed

OTP verification state

Annotations
  • @freezed

Constructors

OTPState.error(String message, {int? attemptsLeft})
const
factory
OTPState.initial()
const
factory
OTPState.requesting()
const
factory
OTPState.sent(String email, String expiresAt, String? tenantId, String? tenantName)
const
factory
OTPState.tenantSelection(String email, List<TenantInfo> tenants, {required bool isNewUser})
const
factory
OTPState.verified()
const
factory
OTPState.verifying()
const
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited