Otp class

OTP state notifier

Annotations
  • @riverpod

Constructors

Otp()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build() OTPState
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reset() → void
setError(String message, {int? attemptsLeft}) → void
setOTPSent(String email, String expiresAt, String? tenantId, String? tenantName) → void
setRequesting() → void
setTenantSelection(String email, List<TenantInfo> tenants, {required bool isNewUser}) → void
setVerified() → void
setVerifying() → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited