prodobitClientProvider top-level property
Provider for Prodobit client instance This should be overridden in your app with your specific configuration
Implementation
final prodobitClientProvider = Provider<ProdobitClient>((ref) {
throw UnimplementedError(
'prodobitClientProvider must be overridden with your Prodobit client configuration',
);
});