InventoryOperations class

Inventory operations notifier

Annotations
  • @riverpod

Constructors

InventoryOperations()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

adjustStock(StockAdjustmentRequest request) Future<StockMovement>
Adjust stock
build() FutureOr<void>
createItem(ItemRequest request) Future<Item>
Create new item
deleteItem(String itemId) Future<void>
Delete item
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
transferStock(StockTransferRequest request) Future<StockMovement>
Transfer stock
updateItem(String itemId, ItemRequest request) Future<Item>
Update item

Operators

operator ==(Object other) bool
The equality operator.
inherited