UserOperations class

User operations notifier

Annotations
  • @riverpod

Constructors

UserOperations()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

activateUser(String userId) Future<void>
Activate user
build() FutureOr<void>
deactivateUser(String userId) Future<void>
Deactivate user
inviteUser({required String email, required List<String> roles, String? firstName, String? lastName}) Future<void>
Invite new user
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
updateProfile({String? firstName, String? lastName, String? avatar, Map<String, dynamic>? metadata}) Future<UserData>
Update current user profile
updateUserRoles({required String userId, required List<String> roles}) Future<UserData>
Update user roles

Operators

operator ==(Object other) bool
The equality operator.
inherited