AssetAssignmentService class
Service for asset assignment operations (zimmet)
Constructors
- AssetAssignmentService(ApiClient _apiClient)
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createAssignment(
CreateAssetAssignmentRequest request) → Future< AssetAssignment> - Create new asset assignment
-
deleteAssignment(
String assignmentId) → Future< void> - Delete assignment
-
getActiveAssignments(
String assignedTo) → Future< List< AssetAssignment> > - Get active assignments for a user/department/location
-
getAssetAssignmentHistory(
String assetId) → Future< List< AssetAssignment> > - Get assignment history for an asset
-
getAssignment(
String assignmentId) → Future< AssetAssignment> - Get assignment by ID
-
getAssignments(
{String? assetId, String? assignedTo, String? assignedType, String? status}) → Future< List< AssetAssignment> > - Get all assignments with optional filtering
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
returnAssignment(
String assignmentId, {String? returnCondition}) → Future< AssetAssignment> - Return an assignment
-
toString(
) → String -
A string representation of this object.
inherited
-
transferAssignment(
String assignmentId, TransferAssignmentRequest request) → Future< AssetAssignment> - Transfer an assignment to another user/department/location
-
updateAssignment(
String assignmentId, UpdateAssetAssignmentRequest request) → Future< AssetAssignment> - Update assignment
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited