AssetIssueService class

Service for asset issue management operations

Constructors

AssetIssueService(ApiClient _apiClient)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

acknowledgeAssetIssue(String issueId) Future<AssetIssue>
Acknowledge asset issue
closeAssetIssue(String issueId) Future<AssetIssue>
Close asset issue
createAssetIssue(CreateAssetIssueRequest request) Future<AssetIssue>
Create new asset issue
deleteAssetIssue(String issueId) Future<void>
Delete asset issue
getAssetIssue(String issueId) Future<AssetIssue>
Get asset issue by ID
getAssetIssues({QueryParams? query}) Future<List<AssetIssue>>
Get all asset issues
getAssetIssuesByAssetId(String assetId) Future<List<AssetIssue>>
Get asset issues by asset ID
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolveAssetIssue(String issueId, {required String resolutionNotes, String? rootCause, String? correctiveActions, String? preventiveActions}) Future<AssetIssue>
Resolve asset issue
toString() String
A string representation of this object.
inherited
updateAssetIssue(String issueId, UpdateAssetIssueRequest request) Future<AssetIssue>
Update asset issue

Operators

operator ==(Object other) bool
The equality operator.
inherited