FileService class

Service for file upload and management

Constructors

FileService(ApiClient _apiClient)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

deleteFile(String fileId) Future<void>
Delete file
getFile(String fileId) Future<FileUploadResponse>
Get file info by ID
listFiles({QueryParams? query}) Future<PaginatedResponse<FileUploadResponse>>
List files
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
uploadFile(String filePath, {String fieldName = 'file', Map<String, dynamic>? metadata, void onProgress(double progress)?}) Future<FileUploadResponse>
Upload a file

Operators

operator ==(Object other) bool
The equality operator.
inherited