LocationService class
Service for location management operations
Constructors
- LocationService(ApiClient _apiClient)
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createLocation(
{required String name, required String code, String? description, String? type, String? parentId, Address? address, ContactInfo? contactInfo, Map< String, dynamic> ? metadata}) → Future<Location> - Create new location
-
deleteLocation(
String locationId) → Future< void> - Delete location
-
getLocation(
String locationId) → Future< Location> - Get location by ID
-
getLocations(
{QueryParams? query}) → Future< List< Location> > - Get all locations
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
updateLocation(
String locationId, {String? name, String? code, String? description, String? type, String? status, String? parentId, Address? address, ContactInfo? contactInfo, Map< String, dynamic> ? metadata}) → Future<Location> - Update location
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited