MaintenanceService class

Service for maintenance management operations

Constructors

MaintenanceService(ApiClient _apiClient)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

completeMaintenanceRecord(String recordId, {required String performedBy, int? durationHours, String? notes, String? issuesFound, Map<String, dynamic>? partsReplaced, Map<String, dynamic>? materialsUsed}) Future<MaintenanceRecord>
Complete maintenance record
createMaintenancePlan(CreateMaintenancePlanRequest request) Future<MaintenancePlan>
Create new maintenance plan
createMaintenanceRecord(CreateMaintenanceRecordRequest request) Future<MaintenanceRecord>
Create new maintenance record
deleteMaintenancePlan(String planId) Future<void>
Delete maintenance plan
deleteMaintenanceRecord(String recordId) Future<void>
Delete maintenance record
getMaintenancePlan(String planId) Future<MaintenancePlan>
Get maintenance plan by ID
getMaintenancePlans({QueryParams? query}) Future<List<MaintenancePlan>>
Get all maintenance plans
getMaintenancePlansByAssetId(String assetId) Future<List<MaintenancePlan>>
Get maintenance plans by asset ID
getMaintenanceRecord(String recordId) Future<MaintenanceRecord>
Get maintenance record by ID
getMaintenanceRecords({QueryParams? query}) Future<List<MaintenanceRecord>>
Get all maintenance records
getMaintenanceRecordsByAssetId(String assetId) Future<List<MaintenanceRecord>>
Get maintenance records by asset ID
getMaintenanceRecordsByPlanId(String planId) Future<List<MaintenanceRecord>>
Get maintenance records by plan ID
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
updateMaintenancePlan(String planId, UpdateMaintenancePlanRequest request) Future<MaintenancePlan>
Update maintenance plan
updateMaintenanceRecord(String recordId, UpdateMaintenanceRecordRequest request) Future<MaintenanceRecord>
Update maintenance record

Operators

operator ==(Object other) bool
The equality operator.
inherited