ManufacturingService class

Manufacturing service for BOM and ECO management

Constructors

ManufacturingService(ApiClient _apiClient)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addBomComponent(String bomId, CreateBomComponentRequest request) Future<BomComponent>
Add component to BOM
approveEco(String ecoId, ApproveEcoRequest request) Future<Eco>
Approve ECO
cloneBom(String bomId, CloneBomRequest request) Future<Bom>
Clone existing BOM
createBom(CreateBomRequest request) Future<Bom>
Create new BOM
createBomQuick(CreateBomQuickRequest request) Future<Bom>
Create BOM quickly
createEco(CreateEcoRequest request) Future<Eco>
Create new ECO
deleteBom(String bomId) Future<void>
Delete BOM
deleteBomComponent(String bomId, String componentId) Future<void>
Delete BOM component
getBomById(String bomId) Future<Bom>
Get BOM by ID
getBomComponents(String bomId, {QueryParams? query}) Future<PaginatedResponse<BomComponent>>
Get BOM components
getBomExplosion(String bomId) Future<List<BomExplosionItem>>
Get BOM explosion view
getBomLeadTime(String bomId) Future<BomLeadTimeAnalysis>
Get BOM lead time analysis
getBoms({QueryParams? query}) Future<PaginatedResponse<Bom>>
Get BOMs with filtering
getBomStats(String bomId) Future<BomStats>
Get BOM statistics
getEcoById(String ecoId) Future<Eco>
Get ECO by ID
getEcos({EcoFilters? filters}) Future<PaginatedResponse<Eco>>
Get ECOs with filtering
getWorkOrders({QueryParams? query}) Future<PaginatedResponse<WorkOrder>>
Get work orders
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rejectEco(String ecoId, RejectEcoRequest request) Future<Eco>
Reject ECO
runMrpRequirements({List<String>? itemIds, DateTime? planningHorizon, Map<String, dynamic>? parameters}) Future<Map<String, dynamic>>
Run MRP requirements calculation
toString() String
A string representation of this object.
inherited
updateBom(String bomId, UpdateBomRequest request) Future<Bom>
Update BOM
updateBomComponent(String bomId, String componentId, UpdateBomComponentRequest request) Future<BomComponent>
Update BOM component
updateEco(String ecoId, UpdateEcoRequest request) Future<Eco>
Update ECO

Operators

operator ==(Object other) bool
The equality operator.
inherited