TaskService class
Service for task management operations
Constructors
- TaskService(ApiClient _apiClient)
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
assignTask(
String taskId, {required String assigneeId}) → Future< Task> - Assign task
-
blockTask(
String taskId, {required String blockingReason}) → Future< Task> - Block task
-
completeTask(
String taskId, {String? completionNotes, int? actualHours}) → Future< Task> - Complete task
-
createTask(
CreateTaskRequest request) → Future< Task> - Create new task
-
createTaskDependency(
CreateTaskDependencyRequest request) → Future< TaskDependency> - Create task dependency
-
deleteTask(
String taskId) → Future< void> - Delete task
-
deleteTaskDependency(
String dependencyId) → Future< void> - Delete task dependency
-
getTask(
String taskId) → Future< Task> - Get task by ID
-
getTaskDependencies(
String taskId) → Future< List< TaskDependency> > - Get task dependencies by task ID
-
getTasks(
{QueryParams? query}) → Future< List< Task> > - Get all tasks
-
getTasksByAssetId(
String assetId) → Future< List< Task> > - Get tasks by asset ID
-
getTasksByAssigneeId(
String assigneeId) → Future< List< Task> > - Get tasks by assignee ID
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
startTask(
String taskId) → Future< Task> - Start task
-
toString(
) → String -
A string representation of this object.
inherited
-
unblockTask(
String taskId) → Future< Task> - Unblock task
-
updateTask(
String taskId, UpdateTaskRequest request) → Future< Task> - Update task
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited