TenantService class

Constructors

TenantService(ApiClient _apiClient)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

acceptInvitation(String token) Future<TenantMember>
Accept a tenant invitation
createInvitation(String tenantId, CreateInvitationRequest request) Future<TenantInvitation>
Create a new tenant invitation
createTenant(CreateTenantRequest request) Future<Tenant>
Create a new tenant
deleteTenant(String tenantId) Future<void>
Delete a tenant
getInvitationByToken(String token) Future<TenantInvitation>
Get invitation details by token
getTenant(String tenantId) Future<Tenant>
Get a specific tenant by ID
getTenantInvitations(String tenantId, {TenantInvitationFilters? filters}) Future<PaginatedResponse<TenantInvitation>>
Get all invitations for a tenant with optional filters
getTenantMembers(String tenantId, {TenantMemberFilters? filters}) Future<PaginatedResponse<TenantMember>>
Get all members of a tenant with optional filters
getTenantRoles(String tenantId) Future<List<TenantRole>>
Get all roles for a tenant
getTenants({TenantFilters? filters}) Future<PaginatedResponse<Tenant>>
Get all tenants with optional filters
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeMember(String tenantId, String memberId) Future<void>
Remove a member from the tenant
toString() String
A string representation of this object.
inherited
updateMembership(String tenantId, String memberId, UpdateMembershipRequest request) Future<TenantMember>
Update a tenant member's role or permissions
updateTenant(String tenantId, UpdateTenantRequest request) Future<Tenant>
Update an existing tenant

Operators

operator ==(Object other) bool
The equality operator.
inherited