UserService class

Service for user management operations

Constructors

UserService(ApiClient _apiClient)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

activateUser(String userId) Future<void>
Activate user
deactivateUser(String userId) Future<void>
Deactivate user
getCurrentProfile() Future<UserData>
Get current user profile
getUserById(String userId) Future<UserData>
Get user by ID
inviteUser({required String email, required List<String> roles, String? firstName, String? lastName}) Future<void>
Invite user to organization
listUsers({QueryParams? query}) Future<PaginatedResponse<UserData>>
List users in organization
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
updateProfile({String? firstName, String? lastName, String? avatar, Map<String, dynamic>? metadata}) Future<UserData>
Update current user profile
updateUserRoles({required String userId, required List<String> roles}) Future<UserData>
Update user roles

Operators

operator ==(Object other) bool
The equality operator.
inherited