ErrorCodes class
Error codes
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- authRequired → const String
- conflict → const String
- forbidden → const String
- invalidCredentials → const String
- invalidToken → const String
- notFound → const String
- rateLimitExceeded → const String
- refreshFailed → const String
- serverError → const String
- tokenExpired → const String
- validationError → const String