StockMovementTypes class

Stock movement types

Constructors

StockMovementTypes()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

adjustment → const String
consumption → const String
production → const String
stockIn → const String
stockOut → const String
transfer → const String