isNotNullOrEmpty property
bool
get
isNotNullOrEmpty
Check if string is not null and not empty
Implementation
bool get isNotNullOrEmpty => !isNullOrEmpty;
Check if string is not null and not empty
bool get isNotNullOrEmpty => !isNullOrEmpty;