ValidationException class
Exception thrown when validation fails
- Inheritance
-
- Object
- ProdobitException
- ValidationException
Constructors
-
ValidationException(String message, {String? code, Map<
String, dynamic> ? details, String? field, List<ValidationViolation> violations = const []}) -
const
-
ValidationException.fromViolations(List<
ValidationViolation> violations, {String? message}) -
Create from validation errors
factory
Properties
- code → String?
-
finalinherited
-
details
→ Map<
String, dynamic> ? -
finalinherited
- field → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
violations
→ List<
ValidationViolation> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited