LoginResponseData class sealed
Login response data model
- Annotations
-
- @freezed
Constructors
-
LoginResponseData({required UserData user, required SessionData session, required AuthMethodData authMethod, required bool isNewUser, String? refreshToken, List<
TenantMembership> ? tenantMemberships}) -
constfactory
-
LoginResponseData.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited