TenantMembership class sealed
Tenant membership model (extended with role information from API responses)
- Annotations
-
- @freezed
Constructors
-
TenantMembership({required String id, required String userId, required String tenantId, required String roleId, required String roleName, required String status, required Map<
String, dynamic> permissions, required String accessLevel, required Map<String, dynamic> resourceRestrictions, required String insertedAt, required String updatedAt, String? roleDescription, String? roleColor, Map<String, dynamic> ? ipRestrictions, Map<String, dynamic> ? timeRestrictions, String? expiresAt, String? invitedBy, String? invitedAt, String? joinedAt, String? lastLoginAt, String? deletedAt}) -
constfactory
-
TenantMembership.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited