UpdateCalibrationPlanRequest class
sealed
Constructors
-
UpdateCalibrationPlanRequest({String? name, String? description, String? type, String? frequency, String? status, DateTime? startDate, DateTime? endDate, DateTime? nextCalibrationDate, int? intervalDays, int? intervalMonths, String? calibrationStandard, String? referenceStandard, String? acceptanceCriteria, String? toleranceRange, int? estimatedDurationHours, String? defaultAssigneeId, String? externalProviderId, String? calibrationLocation, String? priority, String? instructions, Map<String, dynamic>? checklistItems, List<String>? requiredEquipment, String? environmentalConditions, bool? requiresCertificate, int? certificateValidityDays, List<String>? regulatoryRequirements, List<String>? complianceStandards, bool? autoCreateTask, int? taskCreationLeadDays, int? alertBeforeDays, List<String>? alertRecipients, List<String>? imageIds, List<String>? documentIds, String? procedureDocumentId})
-
const
factory
-
UpdateCalibrationPlanRequest.fromJson(Map<String, dynamic> json)
-
factory
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited