UpdateCalibrationRecordRequest class
sealed
Constructors
-
UpdateCalibrationRecordRequest({String? status, DateTime? completedDate, String? performedBy, String? externalProviderId, int? durationHours, String? calibrationResult, Map<String, dynamic>? beforeCalibrationValues, Map<String, dynamic>? afterCalibrationValues, Map<String, dynamic>? deviationValues, String? adjustmentsMade, String? notes, String? failureReason, String? certificateNumber, DateTime? certificateIssueDate, DateTime? certificateExpiryDate, String? certificateDocumentId, String? accreditationBody, DateTime? nextRecommendedDate, String? recommendedActions, double? cost, String? currency, List<String>? imageIds, List<String>? documentIds})
-
const
factory
-
UpdateCalibrationRecordRequest.fromJson(Map<String, dynamic> json)
-
factory
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited