Item class sealed

Item model

Available extensions
Annotations
  • @freezed

Constructors

Item({required String id, required String name, required String code, required String type, required String unit, required bool isActive, required AuditInfo auditInfo, String? description, String? category, String? brand, Money? basePrice, Money? costPrice, String? barcode, String? imageUrl, Map<String, dynamic>? specifications, Map<String, dynamic>? metadata})
const
factory
Item.fromJson(Map<String, dynamic> json)
factory

Properties

displayName String

Available on Item, provided by the ItemExtensions extension

Get display name (name with code)
no setter
hashCode int
The hash code for this object.
no setterinherited
hasImage bool

Available on Item, provided by the ItemExtensions extension

Check if item has image
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited