StockEntry class sealed
Stock entry model
- Available extensions
- Annotations
-
- @freezed
Constructors
-
StockEntry({required String id, required String itemId, required String locationId, required double quantity, required double availableQuantity, required double reservedQuantity, required DateTime lastUpdated, double? minQuantity, double? maxQuantity, Money? averageCost, Map<
String, dynamic> ? metadata}) -
constfactory
-
StockEntry.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isLowStock → bool
-
Available on StockEntry, provided by the StockEntryExtensions extension
Check if stock is lowno setter - isOutOfStock → bool
-
Available on StockEntry, provided by the StockEntryExtensions extension
Check if stock is outno setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stockStatus → String
-
Available on StockEntry, provided by the StockEntryExtensions extension
Get stock statusno setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited