CreateStockAdjustmentRequest class sealed
Create stock adjustment request
- Annotations
-
- @freezed
Constructors
-
CreateStockAdjustmentRequest({required String itemId, required String locationId, required double quantity, required String type, required String reason, String? referenceNumber, String? notes, String? lotNumber, String? serialNumber, Map<
String, dynamic> ? metadata}) -
constfactory
-
CreateStockAdjustmentRequest.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited