CreateBomComponentRequest class sealed
Create BOM component request
- Annotations
-
- @freezed
Constructors
-
CreateBomComponentRequest({required String itemId, required double quantity, required String unit, required double unitCost, int? sequence, String? notes, String? specification, bool? isOptional, String? alternativeItemId, double? wastagePercentage, double? leadTime, Map<
String, dynamic> ? attributes}) -
constfactory
-
CreateBomComponentRequest.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited