ProductionOrder class sealed
Production order model
- Annotations
-
- @freezed
Constructors
-
ProductionOrder({required String id, required String orderNumber, required String itemId, required String itemName, required double quantity, required String status, required DateTime startDate, required List<
ProductionOrderMaterial> materials, required DateTime createdAt, DateTime? endDate, String? notes, String? organizationId, DateTime? updatedAt}) -
constfactory
-
ProductionOrder.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited