PartyAddress class sealed
Party address model
- Annotations
-
- @freezed
Constructors
-
PartyAddress({required String id, required String partyId, required String type, required String addressLine1, required bool isPrimary, required bool isActive, String? addressLine2, String? addressLine3, String? city, String? state, String? postalCode, String? country, String? region, String? label, String? notes, double? latitude, double? longitude, DateTime? validFrom, DateTime? validTo, Map<
String, dynamic> ? metadata}) -
constfactory
-
PartyAddress.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited