CreateOrganizationRequest class sealed
Create organization request
- Annotations
-
- @freezed
Constructors
-
CreateOrganizationRequest({required String name, String? legalName, String? shortName, String? description, String? taxId, String? registrationNumber, String? industry, String? website, DateTime? establishedDate, String? notes, List<
String> ? roles, Map<String, dynamic> ? attributes}) -
constfactory
-
CreateOrganizationRequest.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited