CreateGoodsReceiptLineItemRequest class sealed
Create goods receipt line item request
- Annotations
-
- @freezed
Constructors
-
CreateGoodsReceiptLineItemRequest({required String purchaseOrderLineItemId, required double receivedQuantity, String? lotNumber, String? serialNumber, DateTime? expiryDate, String? condition, String? notes, String? storageLocation, Map<
String, dynamic> ? qualityMetrics, Map<String, dynamic> ? attributes}) -
constfactory
-
CreateGoodsReceiptLineItemRequest.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited