CreatePurchaseRequisitionRequest class sealed
Create purchase requisition request
- Annotations
-
- @freezed
Constructors
-
CreatePurchaseRequisitionRequest({required DateTime requiredDate, required String priority, String? department, String? costCenter, String? project, String? justification, String? notes, List<
CreatePurchaseRequisitionLineItemRequest> ? lineItems, Map<String, dynamic> ? metadata}) -
constfactory
-
CreatePurchaseRequisitionRequest.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited