CreateSalesOrderRequest class sealed
Sales order creation request
- Annotations
-
- @freezed
Constructors
-
CreateSalesOrderRequest({required String customerId, required DateTime orderDate, required List<
CreateSalesOrderItemRequest> items, DateTime? deliveryDate, String? notes}) -
constfactory
-
CreateSalesOrderRequest.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited