Task class sealed

Annotations
  • @freezed

Constructors

Task({required String id, required String tenantId, required String title, required String type, required String priority, required String status, required String createdBy, required DateTime insertedAt, required DateTime updatedAt, String? description, String? assigneeId, String? assignedBy, String? parentTaskId, String? relatedAssetId, String? relatedIssueId, String? relatedMaintenancePlanId, String? relatedCalibrationPlanId, String? locationId, DateTime? startDate, DateTime? endDate, DateTime? dueDate, DateTime? completedAt, int? estimatedHours, int? actualHours, int? progressPercentage, Map<String, dynamic>? checklistItems, int? checklistCompletedCount, bool? isRecurring, String? recurrenceInterval, int? recurrenceCount, DateTime? nextOccurrenceDate, String? notes, List<String>? tags, List<String>? imageIds, List<String>? documentIds, String? completionNotes, String? blockingReason, DateTime? deletedAt})
const
factory
Task.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited