AssetService class
Service for asset management operations
Constructors
- AssetService(ApiClient _apiClient)
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createAsset(
CreateAssetRequest request) → Future< Asset> - Create new asset
-
deleteAsset(
String assetId) → Future< void> - Delete asset
-
getAsset(
String assetId) → Future< Asset> - Get asset by ID
-
getAssets(
{QueryParams? query}) → Future< List< Asset> > - Get all assets
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
updateAsset(
String assetId, UpdateAssetRequest request) → Future< Asset> - Update asset
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited