PartyService class
Party service for customer/supplier management
Constructors
- PartyService(ApiClient _apiClient)
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addAddress(
String partyId, CreateAddressRequest request) → Future< PartyAddress> - Add address to party
-
addContactMechanism(
String partyId, CreateContactMechanismRequest request) → Future< ContactMechanism> - Add contact mechanism to party
-
createOrganization(
CreateOrganizationRequest request) → Future< Party> - Create organization with roles and contacts
-
createOrganizationCustomer(
CreateOrganizationCustomerRequest request) → Future< Party> - Create organization customer quickly
-
createOrganizationSupplier(
CreateOrganizationSupplierRequest request) → Future< Party> - Create organization supplier quickly
-
createPerson(
CreatePersonRequest request) → Future< Party> - Create person with roles and contacts
-
createPersonCustomer(
CreatePersonCustomerRequest request) → Future< Party> - Create person customer quickly
-
createPersonSupplier(
CreatePersonSupplierRequest request) → Future< Party> - Create person supplier quickly
-
createPersonWithRoles(
CreatePersonWithRolesRequest request) → Future< Party> - Create person with multiple roles
-
deleteAddress(
String partyId, String addressId) → Future< void> - Delete address
-
deleteContactMechanism(
String partyId, String contactId) → Future< void> - Delete contact mechanism
-
deleteParty(
String partyId) → Future< void> - Delete party
-
getAddresses(
String partyId) → Future< List< PartyAddress> > - Get party addresses
-
getContactMechanisms(
String partyId) → Future< List< ContactMechanism> > - Get party contact mechanisms
-
getCustomers(
{QueryParams? query}) → Future< PaginatedResponse< Party> > - Get all customer parties
-
getEmployeeParties(
{QueryParams? query}) → Future< PaginatedResponse< Party> > - Get employee parties
-
getParties(
{PartySearchFilters? filters}) → Future< PaginatedResponse< Party> > - Get parties with comprehensive filtering
-
getParty(
String partyId) → Future< Party> - Get party with full details
-
getSuppliers(
{QueryParams? query}) → Future< PaginatedResponse< Party> > - Get all supplier parties
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
searchParties(
{required String query, List< String> ? roles, String? type}) → Future<PaginatedResponse< Party> > - Search parties by various criteria
-
toString(
) → String -
A string representation of this object.
inherited
-
updateAddress(
String partyId, String addressId, UpdateAddressRequest request) → Future< PartyAddress> - Update address
-
updateContactMechanism(
String partyId, String contactId, UpdateContactMechanismRequest request) → Future< ContactMechanism> - Update contact mechanism
-
updateParty(
String partyId, UpdatePartyRequest request) → Future< Party> - Update party information
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited