Validators class

Validation utilities for forms and data

Constructors

Validators()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

combine(List<String? Function(String?)> validators) String? Function(String?)
Combine multiple validators
confirmPassword(String? value, String? originalPassword) String?
Validate confirmed password
currencyAmount(String? value, {String? fieldName}) String?
Validate currency amount
email(String? value) String?
Validate email address
itemCode(String? value) String?
Validate item code
maxLength(String? value, int maxLength, {String? fieldName}) String?
Validate maximum length
minLength(String? value, int minLength, {String? fieldName}) String?
Validate minimum length
nonNegativeNumber(String? value, {String? fieldName}) String?
Validate non-negative number
numeric(String? value, {String? fieldName}) String?
Validate numeric value
password(String? value) String?
Validate password
phone(String? value) String?
Validate phone number
positiveNumber(String? value, {String? fieldName}) String?
Validate positive number
required(String? value, {String? fieldName}) String?
Validate required field
url(String? value) String?
Validate URL